littlemcmc.integration.CpuLeapfrogIntegrator
============================================

.. currentmodule:: littlemcmc.integration

.. autoclass:: CpuLeapfrogIntegrator

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~CpuLeapfrogIntegrator.__init__
      ~CpuLeapfrogIntegrator.compute_state
      ~CpuLeapfrogIntegrator.step
   
   

   
   
   